#-----------------------------------------------------------------------------
%{?!dist:	%define	dist	.ok}
#-----------------------------------------------------------------------------
Name		:	sddm
Version		:	0.21.0
Release		:	17.0.10.rel%{?dist}
Summary		:	QML based X11 desktop manager
Group		:	System Environment/Libraries

Packager	:	Osukiss Project	<build-ok@osukiss.org>

License		:	MIT
URL		:	https://github.com/sddm/sddm/releases

Source0		:	%{name}-%{version}.tar.gz
Source1		:	%{name}-ok_addon.tar.gz
Patch0		:	%{name}-%{version}-qt6greeter.patch
#-----------------------------------------------------------------------------
BuildRequires	:	elogind-devel	
BuildRequires	:	extra-cmake-modules
BuildRequires	:	glade
BuildRequires	:	libxcb
BuildRequires	:	pam-devel	
BuildRequires	:	python3-docutils
BuildRequires	:	qt6-qtbase-devel
BuildRequires	:	qt6-qtdeclarative-devel
BuildRequires	:	qt6-qttools-devel
BuildRequires	:	qt6-rpm-macros

Requires	:	/usr/sbin/useradd, /usr/sbin/userdel
Requires	:	/usr/sbin/groupadd, /usr/sbin/groupdel
Requires	:	chkconfig
Requires	:	elogind
Requires	:	lfs-bootscripts
Requires	:	pam
Requires	:	setxkbmap
Requires	:	sddm-astronaut-theme
Requires	:	upower
Requires	:	xrdb

#-----------------------------------------------------------------------------
%description
SDDM is a modern display manager for X11 and Wayland aiming to be
fast, simple and beautiful.
It uses modern technologies like QtQuick, which in turn gives the
designer the ability to create smooth, animated user interfaces.

SDDM is extremely themeable. We put no restrictions on the user
interface design, it is completely up to the designer. We simply
provide a few callbacks to the user interface which can be used
for authentication, suspend etc.

#-----------------------------------------------------------------------------
%files			
%defattr(-,root,root,-)
%doc README.md LICENSE
%config(noreplace) %{_sysconfdir}/pam.d/*
%config(noreplace) %{_sysconfdir}/%{name}.conf
%dir %attr(0755,%{name},%{name}) %{_var}/lib/%{name}
%dir %attr(0755,%{name},%{name}) %{_prefix}/lib/%{name}/%{name}.d
%dir %attr(0755,%{name},%{name}) %{_sysconfdir}/%{name}.d
%{_libexecdir}/%{name}-helper
%{_bindir}/%{name}
%{_bindir}/%{name}-*
%{_datadir}/dbus-1/system.d/*
%{_qt6_archdatadir}/qml/SddmComponents/
%{_datadir}/%{name}/*
%{_libexecdir}/%{name}-helper-start-*
%{_mandir}/man1/%{name}-greeter.1.gz
%{_mandir}/man1/%{name}.1.gz
%{_mandir}/man5/%{name}-state.conf.5.gz
%{_mandir}/man5/%{name}.conf.5.gz


#-----------------------------------------------------------------------------
%pre 
if [ "$1" = 1 ]; then
  /usr/sbin/groupadd				\
	-K GID_MIN=50				\
	-K GID_MAX=99				\
	 %{name}

  /usr/sbin/useradd 				\
	-r					\
	-c "SDDM daemon"			\
	-K SYS_UID_MIN=50			\
	-K SYS_UID_MAX=99			\
	-g %{name}				\
	-s /bin/false				\
	-d %{_var}/lib/%{name}			\
	%{name}
  fi

#-----------------------------------------------------------------------------
#after upgrade or remove
%preun
if [ "$1" = 0 ]; then
  /usr/sbin/userdel %{name}
  (
  /bin/echo -n "%{name}-%{version} has been fully removed on "; date
  ) > %{_var}/log/README-%{name}-removed
  fi

#=============================================================================
%prep
%setup -q
%patch -P 0 -p1

%{__tar} xf %{SOURCE1}

#adjusting sddm pam file (for howdy)
cp -a							\
	%{name}-ok_addon/*.pam services

#-----------------------------------------------------------------------------
#building application
%build

%define	conffile	sddm_org.freedesktop.DisplayManager.conf
sed -i								\
  -e '/UPOWER_SERVICE)/ s:^://:'				\
  src/daemon/PowerManager.cpp

#NOT needed if elogind is replacing ConsoleKit2
#sed -i								\
#  -e '/\$@$/s/exec/& ck-launch-session/'			\
#  data/scripts/Xsession

#adding keyboard 4 layout within Xsetup and xrandr definition
cat %{name}-ok_addon/Xsetup_addon >> data/scripts/Xsetup

cmake								\
	-B _bld							\
	-S .							\
	-D CMAKE_BUILD_TYPE="Release" 				\
	-D CMAKE_INSTALL_PREFIX=%{_prefix}			\
	-D CMAKE_INSTALL_LIBDIR=%{_libdir}			\
	-D CMAKE_BUILD_TYPE=Debug				\
	-D BUILD_MAN_PAGES=ON					\
	-D NO_SYSTEMD=ON					\
	-D ENABLE_JOURNALD=OFF					\
	-D USE_ELOGIND=ON					\
	-D UID_MIN=300						\
	-D INSTALL_PAM_CONFIGURATION=ON				\
      	-D DBUS_CONFIG_FILENAME=%{conffile}			\
	-D SESSION_COMMAND=/etc/X11/xinit/Xsession		\
	-D WAYLAND_SESSION_COMMAND=/etc/sddm/wayland-session	\
	-D BUILD_WITH_QT6=ON					\


cmake								\
	--build							\
	_bld							\
	--parallel %(/usr/bin/getconf _NPROCESSORS_ONLN)	\

#-----------------------------------------------------------------------------
%clean
%{__rm} -rf %{buildroot}

#-----------------------------------------------------------------------------
#installing program
%install
%{__rm} -rf %{buildroot}

DESTDIR=%{buildroot}						\
	cmake							\
	--install						\
	_bld


%{__mkdir_p} %{buildroot}%{_var}/lib/%{name}
%{__mkdir_p} %{buildroot}%{_prefix}/lib/%{name}/%{name}.d
%{__mkdir_p} %{buildroot}%{_sysconfdir}/%{name}.d

#duplicating sddm.conf
cp -a								\
	%{name}-ok_addon/%{name}.conf				\
	%{buildroot}%{_sysconfdir}
	
#selecting the sddm theme
sed -i								\
  -e "s/^Current=/Current=sddm-astronaut-theme/"		\
  -e "s/^InputMethod=/#InputMethod=/"				\
  -e "/^#InputMethod=/ aInputMethod="				\
  %{buildroot}%{_sysconfdir}/%{name}.conf

#-----------------------------------------------------------------------------
%changelog
